@@ -191,7 +191,11 @@ ggit_config_find_global (void)
 	if (git_config_find_global (&buf) == GIT_OK)
 	{
 		path = g_file_new_for_path (buf.ptr);
+#if LIBGIT2_SOVERSION >= 28
+		git_buf_dispose (&buf);
+#else
 		git_buf_free (&buf);
+#endif
 	}
 
 	return path;
@@ -220,7 +224,11 @@ ggit_config_find_system (void)
 	if (git_config_find_system (&buf) == GIT_OK)
 	{
 		path = g_file_new_for_path (buf.ptr);
+#if LIBGIT2_SOVERSION >= 28
+		git_buf_dispose (&buf);
+#else
 		git_buf_free (&buf);
+#endif
 	}
 
 	return path;
