@@ -48,6 +48,10 @@ gboolean                  ggit_index_write                    (GgitIndex  *idx,
 GgitOId                  *ggit_index_write_tree               (GgitIndex  *idx,
                                                                GError    **error);
 
+GgitOId                  *ggit_index_write_tree_to            (GgitIndex       *idx,
+                                                               GgitRepository  *repository,
+                                                               GError         **error);
+
 gboolean                  ggit_index_remove                   (GgitIndex  *idx,
                                                                GFile      *file,
                                                                gint        stage,
@@ -67,6 +71,8 @@ gboolean                  ggit_index_add_path                 (GgitIndex       *
 
 GgitRepository           *ggit_index_get_owner                (GgitIndex  *idx);
 
+gboolean                  ggit_index_has_conflicts            (GgitIndex  *idx);
+
 GgitIndexEntries         *ggit_index_get_entries              (GgitIndex  *idx);
 GgitIndexEntriesResolveUndo *
                           ggit_index_get_entries_resolve_undo (GgitIndex  *idx);
