@@ -160,7 +160,11 @@ credentials_wrap (git_cred     **cred,
 		{
 			if (error)
 			{
+#if LIBGIT2_SOVERSION >= 28
+				git_error_set_str (GIT_ERROR, error->message);
+#else
 				giterr_set_str (GIT_ERROR, error->message);
+#endif
 				g_error_free (error);
 
 				return GIT_ERROR;
