@@ -44,7 +44,6 @@ enum
 	PROP_0,
 	PROP_CHECKOUT_OPTIONS,
 	PROP_FETCH_OPTIONS,
-	PROP_CLONE_CHECKOUT_STRATEGY,
 };
 
 static void
@@ -79,10 +78,6 @@ ggit_submodule_update_options_set_property (GObject      *object,
 		ggit_submodule_update_options_set_fetch_options (options,
 		                                                 g_value_get_boxed (value));
 		break;
-	case PROP_CLONE_CHECKOUT_STRATEGY:
-		ggit_submodule_update_options_set_clone_checkout_strategy (options,
-		                                                           g_value_get_flags (value));
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -108,10 +103,6 @@ ggit_submodule_update_options_get_property (GObject    *object,
 	case PROP_FETCH_OPTIONS:
 		g_value_set_boxed (value, priv->fetch_options);
 		break;
-	case PROP_CLONE_CHECKOUT_STRATEGY:
-		g_value_set_flags (value,
-		                   ggit_submodule_update_options_get_clone_checkout_strategy (options));
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -144,16 +135,6 @@ ggit_submodule_update_options_class_init (GgitSubmoduleUpdateOptionsClass *klass
 	                                                     GGIT_TYPE_FETCH_OPTIONS,
 	                                                     G_PARAM_READWRITE |
 	                                                     G_PARAM_STATIC_STRINGS));
-
-	g_object_class_install_property (object_class,
-	                                 PROP_CLONE_CHECKOUT_STRATEGY,
-	                                 g_param_spec_flags ("clone-checkout-strategy",
-	                                                     "Clone Checkout Strategy",
-	                                                     "Clone checkout strategy",
-	                                                     GGIT_TYPE_CHECKOUT_STRATEGY,
-	                                                     GGIT_CHECKOUT_NONE,
-	                                                     G_PARAM_READWRITE |
-	                                                     G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -171,7 +152,7 @@ ggit_submodule_update_options_init (GgitSubmoduleUpdateOptions *options)
  *
  * Creates a new submodule options object.
  *
- * Returns: a #GgitSubmoduleUpdateOptions.
+ * Returns: (transfer full) (nullable): a #GgitSubmoduleUpdateOptions or %NULL.
  *
  **/
 GgitSubmoduleUpdateOptions *
@@ -211,7 +192,7 @@ _ggit_submodule_update_options_get_submodule_update_options (GgitSubmoduleUpdate
  *
  * Get the checkout options.
  *
- * Returns: (transfer none): a #GgitCheckoutOptions.
+ * Returns: (transfer none) (nullable): a #GgitCheckoutOptions or %NULL.
  *
  **/
 GgitCheckoutOptions *
@@ -268,7 +249,7 @@ ggit_submodule_update_options_set_checkout_options (GgitSubmoduleUpdateOptions *
  *
  * Gets the fetch options.
  *
- * Returns: (transfer none): a #GgitFetchOptions.
+ * Returns: (transfer none) (nullable): a #GgitFetchOptions or %NULL.
  *
  **/
 GgitFetchOptions *
@@ -318,50 +299,4 @@ ggit_submodule_update_options_set_fetch_options (GgitSubmoduleUpdateOptions *opt
 	g_object_notify (G_OBJECT (options), "fetch-options");
 }
 
-/**
- * ggit_submodule_update_options_get_clone_checkout_strategy:
- * @options: a #GgitSubmoduleUpdateOptions.
- *
- * Gets the clone checkout strategy.
- *
- * Returns: the clone checkout strategy.
- */
-GgitCheckoutStrategy
-ggit_submodule_update_options_get_clone_checkout_strategy (GgitSubmoduleUpdateOptions *options)
-{
-	GgitSubmoduleUpdateOptionsPrivate *priv;
-
-	g_return_val_if_fail (GGIT_IS_SUBMODULE_UPDATE_OPTIONS (options), GGIT_CHECKOUT_NONE);
-
-	priv = ggit_submodule_update_options_get_instance_private (options);
-
-	return priv->options.clone_checkout_strategy;
-}
-
-/**
- * ggit_submodule_update_options_set_clone_checkout_strategy:
- * @options: a #GgitSubmoduleUpdateOptions.
- * @checkout_strategy: a #GgitCheckoutStrategy.
- *
- * Sets the clone checkout strategy. Use %GGIT_CHECKOUT_SAFE_CREATE to create
- * all files in the working directory for the newly cloned repository.
- */
-void
-ggit_submodule_update_options_set_clone_checkout_strategy (GgitSubmoduleUpdateOptions *options,
-                                                           GgitCheckoutStrategy        checkout_strategy)
-{
-	GgitSubmoduleUpdateOptionsPrivate *priv;
-
-	g_return_if_fail (GGIT_IS_SUBMODULE_UPDATE_OPTIONS (options));
-
-	priv = ggit_submodule_update_options_get_instance_private (options);
-
-	if (priv->options.clone_checkout_strategy != checkout_strategy)
-	{
-		priv->options.clone_checkout_strategy = checkout_strategy;
-
-		g_object_notify (G_OBJECT (options), "clone-checkout-strategy");
-	}
-}
-
 /* ex:set ts=8 noet: */
