@@ -128,6 +128,10 @@ ASSERT_ENUM (GGIT_MERGE_FAIL_ON_CONFLICT, GIT_MERGE_FAIL_ON_CONFLICT);
 ASSERT_ENUM (GGIT_MERGE_SKIP_REUC, GIT_MERGE_SKIP_REUC);
 ASSERT_ENUM (GGIT_MERGE_NO_RECURSIVE, GIT_MERGE_NO_RECURSIVE);
 
+ASSERT_ENUM (GGIT_PROXY_NONE, GIT_PROXY_NONE);
+ASSERT_ENUM (GGIT_PROXY_AUTO, GIT_PROXY_AUTO);
+ASSERT_ENUM (GGIT_PROXY_SPECIFIED, GIT_PROXY_SPECIFIED);
+
 ASSERT_ENUM (GGIT_REBASE_OPERATION_PICK, GIT_REBASE_OPERATION_PICK);
 ASSERT_ENUM (GGIT_REBASE_OPERATION_REWORD, GIT_REBASE_OPERATION_REWORD);
 ASSERT_ENUM (GGIT_REBASE_OPERATION_EDIT, GIT_REBASE_OPERATION_EDIT);
